@@ -1,6 +1,8 @@
 #include <string.h>
 #include <ctype.h>
 
+#ifdef BUILD_FROM_SOURCE
+#else
 #ifdef __GLIBC__
 __asm__(".symver strlen,strlen@GLIBC_2.2.5");
 __asm__(".symver memcpy,memcpy@GLIBC_2.2.5");
@@ -8,6 +10,7 @@ __asm__(".symver free,free@GLIBC_2.2.5");
 __asm__(".symver isspace,isspace@GLIBC_2.2.5");
 __asm__(".symver fmemopen,fmemopen@GLIBC_2.2.5");
 #endif
+#endif
 
 int __has_only_whitespaces(char* s) {
     unsigned int i;
